# Generated by roxygen2: do not edit by hand

export(SimParamBee)
export(addCastePop)
export(addDrones)
export(addVirginQueens)
export(addWorkers)
export(areDronesPresent)
export(areFathersPresent)
export(areVirginQueensPresent)
export(areWorkersPresent)
export(buildUp)
export(calcBeeAlleleFreq)
export(calcBeeGRMIbd)
export(calcBeeGRMIbs)
export(calcColonyGv)
export(calcColonyPheno)
export(calcColonyValue)
export(calcInheritanceCriterion)
export(calcPerformanceCriterion)
export(calcQueensPHomBrood)
export(calcSelectionCriterion)
export(collapse)
export(combine)
export(createCastePop)
export(createColony)
export(createCrossPlan)
export(createDCA)
export(createDrones)
export(createMatingStationDCA)
export(createMultiColony)
export(createVirginQueens)
export(createWorkers)
export(cross)
export(downsize)
export(downsizePUnif)
export(getCaste)
export(getCasteId)
export(getCastePop)
export(getCasteSex)
export(getCsdAlleles)
export(getCsdGeno)
export(getDrones)
export(getDronesCsdAlleles)
export(getDronesCsdGeno)
export(getDronesGv)
export(getDronesIbdHaplo)
export(getDronesPheno)
export(getDronesQtlGeno)
export(getDronesQtlHaplo)
export(getDronesSegSiteGeno)
export(getDronesSegSiteHaplo)
export(getDronesSnpGeno)
export(getDronesSnpHaplo)
export(getEvents)
export(getFathers)
export(getFathersCsdAlleles)
export(getFathersCsdGeno)
export(getFathersGv)
export(getFathersIbdHaplo)
export(getFathersPheno)
export(getFathersQtlGeno)
export(getFathersQtlHaplo)
export(getFathersSegSiteGeno)
export(getFathersSegSiteHaplo)
export(getFathersSnpGeno)
export(getFathersSnpHaplo)
export(getGv)
export(getIbdHaplo)
export(getId)
export(getLocation)
export(getMisc)
export(getPheno)
export(getPooledGeno)
export(getQtlGeno)
export(getQtlHaplo)
export(getQueen)
export(getQueenAge)
export(getQueenCsdAlleles)
export(getQueenCsdGeno)
export(getQueenGv)
export(getQueenIbdHaplo)
export(getQueenPheno)
export(getQueenQtlGeno)
export(getQueenQtlHaplo)
export(getQueenSegSiteGeno)
export(getQueenSegSiteHaplo)
export(getQueenSnpGeno)
export(getQueenSnpHaplo)
export(getQueenYearOfBirth)
export(getSegSiteGeno)
export(getSegSiteHaplo)
export(getSnpGeno)
export(getSnpHaplo)
export(getVirginQueens)
export(getVirginQueensCsdAlleles)
export(getVirginQueensCsdGeno)
export(getVirginQueensGv)
export(getVirginQueensIbdHaplo)
export(getVirginQueensPheno)
export(getVirginQueensQtlGeno)
export(getVirginQueensQtlHaplo)
export(getVirginQueensSegSiteGeno)
export(getVirginQueensSegSiteHaplo)
export(getVirginQueensSnpGeno)
export(getVirginQueensSnpHaplo)
export(getWorkers)
export(getWorkersCsdAlleles)
export(getWorkersCsdGeno)
export(getWorkersGv)
export(getWorkersIbdHaplo)
export(getWorkersPheno)
export(getWorkersQtlGeno)
export(getWorkersQtlHaplo)
export(getWorkersSegSiteGeno)
export(getWorkersSegSiteHaplo)
export(getWorkersSnpGeno)
export(getWorkersSnpHaplo)
export(hasCollapsed)
export(hasSplit)
export(hasSuperseded)
export(hasSwarmed)
export(isCaste)
export(isColony)
export(isCsdActive)
export(isCsdHeterozygous)
export(isDrone)
export(isDronesPresent)
export(isEmpty)
export(isFather)
export(isFathersPresent)
export(isMultiColony)
export(isNULLColonies)
export(isProductive)
export(isQueen)
export(isQueenPresent)
export(isSimParamBee)
export(isVirginQueen)
export(isVirginQueenPresent)
export(isVirginQueens)
export(isVirginQueensPresent)
export(isWorker)
export(isWorkersPresent)
export(mapCasteToColonyGv)
export(mapCasteToColonyPheno)
export(mapCasteToColonyValue)
export(nCaste)
export(nColonies)
export(nCsdAlleles)
export(nDrones)
export(nDronesColonyPhenotype)
export(nDronesPoisson)
export(nDronesTruncPoisson)
export(nEmptyColonies)
export(nFathers)
export(nFathersPoisson)
export(nFathersTruncPoisson)
export(nHomBrood)
export(nNULLColonies)
export(nQueens)
export(nVirginQueens)
export(nVirginQueensColonyPhenotype)
export(nVirginQueensPoisson)
export(nVirginQueensTruncPoisson)
export(nWorkers)
export(nWorkersColonyPhenotype)
export(nWorkersPoisson)
export(nWorkersTruncPoisson)
export(pHomBrood)
export(pullCastePop)
export(pullColonies)
export(pullDroneGroupsFromDCA)
export(pullDrones)
export(pullInd)
export(pullQueen)
export(pullVirginQueens)
export(pullWorkers)
export(rcircle)
export(reQueen)
export(reduceDroneGeno)
export(reduceDroneHaplo)
export(removeCastePop)
export(removeColonies)
export(removeDrones)
export(removeQueen)
export(removeVirginQueens)
export(removeWorkers)
export(replaceCastePop)
export(replaceDrones)
export(replaceVirginQueens)
export(replaceWorkers)
export(resetEvents)
export(selectColonies)
export(setLocation)
export(setMisc)
export(setQueensYearOfBirth)
export(simulateHoneyBeeGenomes)
export(split)
export(splitPColonyStrength)
export(splitPUnif)
export(supersede)
export(swarm)
export(swarmPUnif)
exportClasses(Colony)
exportClasses(MultiColony)
import(AlphaSimR)
import(Rcpp)
importFrom(R6,R6Class)
importFrom(extraDistr,rtpois)
importFrom(methods,"slot<-")
importFrom(methods,classLabel)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setClassUnion)
importFrom(methods,setMethod)
importFrom(methods,setValidity)
importFrom(methods,show)
importFrom(methods,slot)
importFrom(methods,validObject)
importFrom(stats,na.omit)
importFrom(stats,rbeta)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(utils,packageVersion)
useDynLib(SIMplyBee, .registration = TRUE)
