# SIMplyBee README <img src="vignettes/SIMplyBee_logo_small.png" align="right" height="200"/>

SIMplyBee R package extends [AlphaSimR](https://CRAN.R-project.org/package=AlphaSimR)
for simulating honeybee populations and breeding programmes

## Publication

Obšteter J., Strachan. L. K., Bubnič J., Prešern J., Gorjanc G. 2023. Genetics Selection Evolution, 55, 31. https://doi.org/10.1186/s12711-023-00798-y

## Documentation

http://simplybee.info

## Download

SIMplyBee is available on CRAN. You can install it with 

    install.packages(pkg = "SIMplyBee")

The development (and potentially unstable!) versions of SIMplyBee can be
accessed from the main and devel GitHub branches using:

    # New stable version of SIMplyBee before its submitted to CRAN
    devtools::install_github(repo="HighlanderLab/SIMplyBee@main")

    # Development version of SIMplyBee
    devtools::install_github(repo="HighlanderLab/SIMplyBee@devel")

 <!-- badges: start -->
[![R-CMD-check](https://github.com/HighlanderLab/SIMplyBee/actions/workflows/R-CMD-check.yaml/badge.svg?branch=devel)](https://github.com/HighlanderLab/SIMplyBee/actions/workflows/R-CMD-check.yaml)
  <!-- badges: end -->

<!-- badges: start -->
  [![pages-build-deployment](https://github.com/HighlanderLab/SIMplyBee/actions/workflows/pages/pages-build-deployment/badge.svg)](https://github.com/HighlanderLab/SIMplyBee/actions/workflows/pages/pages-build-deployment)
<!-- badges: end -->

<!-- badges: start -->
[![pkgdown](https://github.com/HighlanderLab/SIMplyBee/actions/workflows/pkgdown.yaml/badge.svg)](https://github.com/HighlanderLab/SIMplyBee/actions/workflows/pkgdown.yaml)
<!-- badges: end -->
